==> s-1.0.0.tgz: package/src/index.js <==
const axios = require('axios')

const request = async (url, functionName = null, args = {}) => {
  const headers = {}
  if (functionName) headers['s-function'] = functionName
  try {
    const res = await axios({
      method: 'post',
      url,
      headers,
      data: args
    })
    return res.data
  } catch (e) {
    console.log(e)
    throw new Error(e.response.data.error)
  }
}

const isDomain = (string) => {
  if (!string || !(/^[a-zA-Z0-9][a-zA-Z0-9-]{1,61}[a-zA-Z0-9](?:\.[a-zA-Z]{2,})+$/.test(string))) return false
  return true
}

const getUrl = (config) => {
  let url
  if (typeof config === 'string') {
    if (isDomain(config)) {
      url = config
    } else {
      url = `https://${config}.execute-api.us-east-1.amazonaws.com/dev/s`
    }
  } else if (typeof config === 'object') {
    if (isDomain(config.url)) {
      url = config.url
    } else {
      if (!config.sid) {
        throw new Error('Please provide an SID or a valid domain')
      }
      const region = config.region || 'us-east-1'
      url = `https://${config.sid}.execute-api.${region}.amazonaws.com/dev/s`
    }
  } else {
    throw new Error('Please provide an SID or a valid domain')
  }
  return url
}

const S = async (config) => {
  const url = getUrl(config)
  const availableFunctions = await request(url)
  return availableFunctions.reduce((accum, functionName) => {
    accum[functionName] = async (args) => request(url, functionName, args)
    return accum
  }, {})
}

if (typeof window !== 'undefined') {
  window.S = S
} else {
  module.exports = S
}

==> s-1.0.1.tgz: package/src/index.js <==
const axios = require('axios')

const request = async (url, functionName = null, args = {}) => {
  const headers = {}
  if (functionName) headers['s-function'] = functionName
  try {
    const res = await axios({
      method: 'post',
      url,
      headers,
      data: args
    })
    return res.data
  } catch (e) {
    console.log(e)
    throw new Error(e.response.data.error)
  }
}

const isDomain = (string) => {
  if (!string || !(/^[a-zA-Z0-9][a-zA-Z0-9-]{1,61}[a-zA-Z0-9](?:\.[a-zA-Z]{2,})+$/.test(string))) return false
  return true
}

const getUrl = (config) => {
  let url
  if (typeof config === 'string') {
    if (isDomain(config)) {
      url = config
    } else {
      url = `https://${config}.execute-api.us-east-1.amazonaws.com/dev/s`
    }
  } else if (typeof config === 'object') {
    if (isDomain(config.url)) {
      url = config.url
    } else {
      if (!config.sid) {
        throw new Error('Please provide an SID or a valid domain')
      }
      const region = config.region || 'us-east-1'
      url = `https://${config.sid}.execute-api.${region}.amazonaws.com/dev/s`
    }
  } else {
    throw new Error('Please provide an SID or a valid domain')
  }
  return url
}

const S = async (config) => {
  const url = getUrl(config)
  const availableFunctions = await request(url)
  return availableFunctions.reduce((accum, functionName) => {
    accum[functionName] = async (args) => request(url, functionName, args)
    return accum
  }, {})
}

module.exports = S

// if (typeof window !== 'undefined') {
//   window.S = S
// } else {
//   module.exports = S
// }
